@@ -81,6 +81,10 @@ public class ApiFacadeException extends WebApplicationException {
 
         int EMPTY_ARRAY_NOT_ALLOWED = 8;
 
+        int INVALID_ACCOUNT_DATA = 9;
+
+        int REDIRECT = 10;
+
         String INVALID_SESSION = "SES-206";
 
         int CLIENT_UPDATE_MANDATORY = 900;
@@ -106,6 +110,8 @@ public class ApiFacadeException extends WebApplicationException {
             return invalidSession();
         } else if (areCredentialsInvalid(code)) {
             return invalidCredentials();
+        } else if (isRedirect(code)) {
+            return redirect(error);
         }
         return create(Status.BAD_REQUEST, code, responseBody.getErrorDescription());
     }
@@ -123,6 +129,10 @@ public class ApiFacadeException extends WebApplicationException {
         return "MSG-1000".equals(code) || "LGI-0006".equals(code);
     }
 
+    private static boolean isRedirect(String code) {
+        return "LGI-0016".equals(code);
+    }
+
     public static ApiFacadeException badRequest(int errorCode, String message) {
         return create(Status.BAD_REQUEST, errorCode, message);
     }
@@ -139,6 +149,10 @@ public class ApiFacadeException extends WebApplicationException {
         return create(Status.UNAUTHORIZED, Code.INVALID_SESSION, "Your session was invalidated. Please try again.");
     }
 
+    public static ApiFacadeException redirect(String location) {
+        return create(Status.TEMPORARY_REDIRECT, Code.REDIRECT, location);
+    }
+
     public static ApiFacadeException missingHeader(String name) {
         return create(Status.BAD_REQUEST, Code.MISSING_HEADER, "Header missing: " + name);
     }
@@ -209,4 +223,8 @@ public class ApiFacadeException extends WebApplicationException {
         return create(Status.NOT_FOUND, Code.ACCOUNT_NOT_FOUND, "Account not found: " + accountId);
     }
 
+    public static ApiFacadeException invalidAccountData() {
+        return create(Status.BAD_REQUEST, Code.INVALID_ACCOUNT_DATA, "Invalid account data");
+    }
+
 }
