@@ -72,6 +72,7 @@ import com.openexchange.mobile.api.facade.models.Config;
 import com.openexchange.mobile.api.facade.models.CreatedFolder;
 import com.openexchange.mobile.api.facade.models.ExamineResult;
 import com.openexchange.mobile.api.facade.models.Folder;
+import com.openexchange.mobile.api.facade.models.MailAccountData;
 import com.openexchange.mobile.api.facade.utils.ListUtil;
 import com.openexchange.mobile.api.facade.utils.MapFunction;
 
@@ -128,7 +129,21 @@ public class FoldersService {
     }
 
     private Account addFoldersImpl(ConnectorFactory connectorFactory, SessionData sessionData, Account account, String language, boolean isNamespaceSet) {
-        List<Folder> folders = retrieveFolders(connectorFactory, sessionData, account, language);
+        List<Folder> folders = retrieveFolders(connectorFactory, sessionData, account.getRootFolderId(), account.getArchiveFolderId(), language);
+        examineFolders(connectorFactory, sessionData, folders);
+        account = account.withFolders(folders);
+        adjustFolderParents(account, account.isPrimaryAccount() && isNamespaceSet);
+        return account;
+    }
+
+    public MailAccountData addFolders(ConnectorFactory connectorFactory, SessionData sessionData, MailAccountData account, String language) {
+        Config config = retrieveConfiguration(connectorFactory, sessionData);
+        boolean isNamespaceSet = "INBOX/".equals(config.getNamespace());
+        return addFoldersImpl(connectorFactory, sessionData, account, language, isNamespaceSet);
+    }
+
+    private MailAccountData addFoldersImpl(ConnectorFactory connectorFactory, SessionData sessionData, MailAccountData account, String language, boolean isNamespaceSet) {
+        List<Folder> folders = retrieveFolders(connectorFactory, sessionData, account.getRootFolderId(), account.getArchiveFolderId(), language);
         examineFolders(connectorFactory, sessionData, folders);
         account = account.withFolders(folders);
         adjustFolderParents(account, account.isPrimaryAccount() && isNamespaceSet);
@@ -141,10 +156,8 @@ public class FoldersService {
         return ConfigConnector.map(response);
     }
 
-    private List<Folder> retrieveFolders(ConnectorFactory connectorFactory, SessionData sessionData, Account account, String language) {
+    private List<Folder> retrieveFolders(ConnectorFactory connectorFactory, SessionData sessionData, String rootFolderId, String archiveFolderId, String language) {
         boolean includeNonPrivateFolders = sessionData.getConfiguration().isIncludeNonPrivateFolders();
-        String rootFolderId = account.getRootFolderId();
-        String archiveFolderId = account.getArchiveFolderId();
         AllFoldersConnector connector = connectorFactory.getAllFoldersConnector(sessionData, rootFolderId, language);
         FoldersResponseMto response = connector.execute();
         FoldersMto data = response.getData();
@@ -200,4 +213,19 @@ public class FoldersService {
         }
     }
 
+    private void adjustFolderParents(MailAccountData account, boolean isNamespaceSet) {
+        if (!isNamespaceSet) {
+            return;
+        }
+        Folder inboxFolder = account.getStandardFolders().getInboxFolder();
+        if (inboxFolder != null) {
+            String inboxFolderId = inboxFolder.getId();
+            String parentFolderId = inboxFolder.getParentId();
+            for (Folder folder : account.getFolders()) {
+                if (inboxFolderId.equals(folder.getParentId())) {
+                    folder.setParentId(parentFolderId);
+                }
+            }
+        }
+    }
 }
